#!/usr/bin/env python3

# Copyright (c) Facebook, Inc. and its affiliates.
# All rights reserved.
#
# This source code is licensed under the BSD-style license found in the
# LICENSE file in the root directory of this source tree.

from .api import get_env_variable_or_raise, get_socket_with_port, macros  # noqa: F401



from typing import Tuple
from .optimizer import _params_t, Optimizer

class Adadelta(Optimizer):
    def __init__(self, params: _params_t, lr: float=..., rho: float=..., eps: float=..., weight_decay: float=...) -> None: ...
